@@ -15,6 +15,8 @@
  * limitations under the License.
  */
 #include "chxj_tag_util.h"
+#include "chxj_url_encode.h"
+#include "chxj_str_util.h"
 
 
 /**
@@ -585,6 +587,52 @@ qs_get_parse_attr(Doc *doc, Node *tag, apr_pool_t *pool)
   return NULL;
 }
 
+
+char *
+chxj_form_action_to_hidden_tag(request_rec *r, apr_pool_t *pool, const char *str, int xmlFlag, int post)
+{
+  char *s = apr_pstrdup(pool, str);
+  if (!s) return NULL;
+  if (chxj_starts_with(s, "http://") || chxj_starts_with(s, "https://")) {
+    apr_uri_t url;
+    apr_uri_parse(pool, s, &url);
+    if (url.hostname && strcasecmp(url.hostname, r->hostname) != 0) {
+      return NULL;
+    }
+  }
+  s = strchr(s, '?');
+  if (!s) return NULL;
+  s++;
+  char *result = NULL;
+
+  char *pstat;
+  char *pstat2;
+  for (;;) {
+    char *pair = apr_strtok(s, "&", &pstat);
+    if (! pair) break;
+    s = NULL;
+    char *key = apr_strtok(pair, "=",  &pstat2);
+    char *val = "";
+    if (key) {
+      val = apr_strtok(NULL, "=", &pstat2);
+      if (!val) val = "";
+    }
+    char *tmp = NULL;
+    if (! post || strcasecmp(key, "_chxj_cc") == 0 || strcasecmp(key, "_chxj_nc") == 0) {
+      tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+    }
+    else {
+      tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"_chxj_qs_%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+    }
+    if (result) {
+      result = apr_pstrcat(pool, result, tmp, NULL);
+    }
+    else {
+      result = tmp;
+    }
+  }
+  return result;
+}
 /*
  * vim:ts=2 et
  */
