@@ -68,6 +68,7 @@
 #endif
 #include "chxj_serf.h"
 #include "chxj_add_device_env.h"
+#include "chxj_conv_z2h.h"
 
 
 #define CHXJ_VERSION_PREFIX PACKAGE_NAME "/"
@@ -401,6 +402,9 @@ chxj_convert(request_rec *r, const char **src, apr_size_t *len, device_table *sp
                                                               entryp, 
                                                               cookie);
     }
+    if (dst && *len) {
+      dst = chxj_conv_z2h(r, dst, len, entryp);
+    }
   }
   ap_set_content_length(r, *len);
 
@@ -413,6 +417,7 @@ chxj_convert(request_rec *r, const char **src, apr_size_t *len, device_table *sp
     *cookiep = cookie;
   }
 
+
   DBG(r, "REQ[%X] end of chxj_convert()", (unsigned int)(apr_size_t)r);
 
   return dst;
@@ -2189,6 +2194,42 @@ cmd_convert_rule(cmd_parms *cmd, void *mconfig, const char *arg)
         newrule->action |= CONVRULE_COOKIE_ON_BIT;
       }
       break;
+
+    case 'Z':
+    case 'z':
+      if (strcasecmp(CONVRULE_Z2H_ON_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_ON_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_OFF_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_OFF_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_ALPHA_ON_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_ALPHA_ON_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_ALPHA_OFF_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_ALPHA_OFF_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_NUM_ON_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_NUM_ON_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_NUM_OFF_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_NUM_OFF_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_ALL_ON_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_ON_BIT | CONVRULE_Z2H_ALPHA_ON_BIT | CONVRULE_Z2H_NUM_ON_BIT;
+      }
+      else
+      if (strcasecmp(CONVRULE_Z2H_NUM_OFF_CMD, action) == 0) {
+        newrule->action |= CONVRULE_Z2H_OFF_BIT | CONVRULE_Z2H_ALPHA_OFF_BIT | CONVRULE_Z2H_NUM_OFF_BIT;
+      }
+      break;
+
     default:
       break;
     }
